/**
 *
 * This is a high-level construct that demonstrates
 * how to use the static site CloudFrontWebDistribution
 * together with the ECS Stack.
 *
 * CloudFront allows for both the static site and
 * the `/api` calls to be served from the same
 * domain (app.example.com, for example).
 *
 * This would be a good setup if you are using a Vue or React
 * static website (such as an SPA) and your Django app's
 * REST API uses either JWT (with HttpOnly refresh token)
 * or Session-based API authentication.
 *
 * If you are using a Vue app and a Django app and don't mind
 * storing JWT on the browser's localStorage, you can also use this
 * approach, but you can also setup the frontend and backend on
 * different domains.
 *
 **/
import * as cdk from '@aws-cdk/core';
/**
 * Django and Vue application stack props.
 *
 * @stability stable
 */
export interface DjangoVueProps {
    /**
     * Certificate ARN for looking up the Certificate to use for CloudFront and ALB.
     *
     * @stability stable
     */
    readonly certificateArn?: string;
    /**
     * @stability stable
     */
    readonly domainName: string;
    /**
     * @stability stable
     */
    readonly zoneName: string;
}
/**
 * Construct for projects using Django backend and static site for frontend.
 *
 * @stability stable
 */
export declare class DjangoVue extends cdk.Construct {
    /**
     * @stability stable
     */
    constructor(scope: cdk.Construct, id: string, props: DjangoVueProps);
}
