import * as elbv2 from '@aws-cdk/aws-elasticloadbalancingv2';
import * as s3 from '@aws-cdk/aws-s3';
import * as cdk from '@aws-cdk/core';
/**
 * @stability stable
 */
export interface StaticSiteProps {
    /**
     * Path to static site distribution directory.
     *
     * @stability stable
     */
    readonly pathToDist: string;
    /**
     * The zoneName of the hosted zone.
     *
     * @stability stable
     */
    readonly zoneName: string;
    /**
     * Domain name for static site (including sub-domain).
     *
     * @stability stable
     */
    readonly frontendDomainName: string;
    /**
     * Certificate ARN.
     *
     * @stability stable
     */
    readonly certificateArn?: string;
    /**
     * Load Balancer.
     *
     * If the backend and the frontend are served on the same site,
     * this is required. CloudFront will act as a proxy, doing
     * path-based routing to the backend load balancer (for example,
     * all requests starting with `/api/*`)
     *
     * @stability stable
     */
    readonly loadBalancer?: elbv2.ApplicationLoadBalancer;
    /**
     * Assets bucket.
     *
     * Proxy requests to /static and /media to the assets bucket
     *
     * @stability stable
     */
    readonly assetsBucket?: s3.Bucket;
}
/**
 * Construct for a static website hosted with S3 and CloudFront.
 *
 * https://github.com/aws-samples/aws-cdk-examples/blob/master/typescript/static-site/static-site.ts
 *
 * @stability stable
 */
export declare class StaticSite extends cdk.Construct {
    /**
     * @stability stable
     */
    constructor(scope: cdk.Construct, id: string, props: StaticSiteProps);
}
